@@ -62,19 +62,6 @@ def load_module_actions(mod):
     return False
 
 
-def load_standard():
-    import jaseci.actions.standard.net  # noqa
-    import jaseci.actions.standard.rand  # noqa
-    import jaseci.actions.standard.request  # noqa
-    import jaseci.actions.standard.std  # noqa
-    import jaseci.actions.standard.file  # noqa
-    import jaseci.actions.standard.vector  # noqa
-    import jaseci.actions.standard.date  # noqa
-
-
-load_standard()
-
-
 def load_preconfig_actions(hook):
     import json
 
@@ -106,6 +93,8 @@ def get_global_actions(hook):
             or i.startswith("rand.")
             or i.startswith("vector.")
             or i.startswith("request.")
+            or i.startswith("date.")
+            or i.startswith("jaseci.")
         ):
             global_action_list.append(
                 action(
