@@ -13,66 +13,66 @@ NoneType = type(None)
 
 
 class JAC_TYPE:
-    STR = 'JAC_TYPE.STR'
-    INT = 'JAC_TYPE.INT'
-    FLOAT = 'JAC_TYPE.FLOAT'
-    LIST = 'JAC_TYPE.LIST'
-    DICT = 'JAC_TYPE.DICT'
-    BOOL = 'JAC_TYPE.BOOL'
-    NODE = 'JAC_TYPE.NODE'
-    EDGE = 'JAC_TYPE.EDGE'
-    TYPE = 'JAC_TYPE.TYPE'
-    NULL = 'JAC_TYPE.NULL'
+    STR = "JAC_TYPE.STR"
+    INT = "JAC_TYPE.INT"
+    FLOAT = "JAC_TYPE.FLOAT"
+    LIST = "JAC_TYPE.LIST"
+    DICT = "JAC_TYPE.DICT"
+    BOOL = "JAC_TYPE.BOOL"
+    NODE = "JAC_TYPE.NODE"
+    EDGE = "JAC_TYPE.EDGE"
+    TYPE = "JAC_TYPE.TYPE"
+    NULL = "JAC_TYPE.NULL"
 
 
 def jac_type_wrap(val):
-    if(isinstance(val, type)):
-        if(val == str):
+    if isinstance(val, type):
+        if val == str:
             val = JAC_TYPE.STR
-        elif(val == int):
+        elif val == int:
             val = JAC_TYPE.INT
-        elif(val == float):
+        elif val == float:
             val = JAC_TYPE.FLOAT
-        elif(val == list):
+        elif val == list:
             val = JAC_TYPE.LIST
-        elif(val == jac_set):
+        elif val == jac_set:
             val = JAC_TYPE.LIST
-        elif(val == dict):
+        elif val == dict:
             val = JAC_TYPE.DICT
-        elif(val == bool):
+        elif val == bool:
             val = JAC_TYPE.BOOL
-        elif(val == node):
+        elif val == node:
             val = JAC_TYPE.NODE
-        elif(val == edge):
+        elif val == edge:
             val = JAC_TYPE.EDGE
-        elif(val == type):
+        elif val == type:
             val = JAC_TYPE.TYPE
-        elif(val == NoneType):
+        elif val == NoneType:
             val = JAC_TYPE.NULL
     return val
 
 
 def jac_type_unwrap(val):
-    if(type(val) == str and val.startswith('JAC_TYPE.')):
-        if(val == JAC_TYPE.STR):
+    if type(val) == str and val.startswith("JAC_TYPE."):
+        if val == JAC_TYPE.STR:
             val = str
-        elif(val == JAC_TYPE.INT):
+        elif val == JAC_TYPE.INT:
             val = int
-        elif(val == JAC_TYPE.FLOAT):
+        elif val == JAC_TYPE.FLOAT:
             val = float
-        elif(val == JAC_TYPE.LIST):
+        elif val == JAC_TYPE.LIST:
             val = list
-        elif(val == JAC_TYPE.DICT):
+        elif val == JAC_TYPE.DICT:
             val = dict
-        elif(val == JAC_TYPE.BOOL):
+        elif val == JAC_TYPE.BOOL:
             val = bool
-        elif(val == JAC_TYPE.NODE):
+        elif val == JAC_TYPE.NODE:
             val = node
-        elif(val == JAC_TYPE.EDGE):
+        elif val == JAC_TYPE.EDGE:
             val = edge
-        elif(val == JAC_TYPE.TYPE):
+        elif val == JAC_TYPE.TYPE:
             val = type
-        elif(val == JAC_TYPE.NULL):
+        elif val == JAC_TYPE.NULL:
             val = NoneType
     return val
 
@@ -83,30 +83,29 @@ def is_jac_elem(val):
 
 
 def jac_elem_wrap(val, serialize_mode=False):
-    if(serialize_mode):
+    if serialize_mode:
         val = val.serialize()
     else:
-        val = val.id.urn.replace('urn', 'jac')
+        val = val.id.urn.replace("urn", "jac")
     return val
 
 
 def jac_elem_unwrap(val, parent):
-    val = parent._h.get_obj(
-        parent._m_id, uuid.UUID(val.replace('jac', 'urn')))
+    val = parent._h.get_obj(parent._m_id, uuid.UUID(val.replace("jac", "urn")))
     return val
 
 
 def jac_wrap_value(val, serialize_mode=False):
     """converts all elements to uuids in lists etc"""
     val = jac_type_wrap(val)
-    if (isinstance(val, element)):
+    if isinstance(val, element):
         val = jac_elem_wrap(val, serialize_mode=serialize_mode)
-    elif(isinstance(val, jac_set)):
+    elif isinstance(val, jac_set):
         val = jac_wrap_value(list(val), serialize_mode)
-    elif (isinstance(val, list)):
+    elif isinstance(val, list):
         for i in range(len(val)):
             val[i] = jac_wrap_value(val[i], serialize_mode)
-    elif (isinstance(val, dict)):
+    elif isinstance(val, dict):
         for i in val.keys():
             val[i] = jac_wrap_value(val[i], serialize_mode)
     return val
@@ -114,18 +113,18 @@ def jac_wrap_value(val, serialize_mode=False):
 
 def jac_unwrap_value(val, parent):
     """Reference to variables value"""
-    if(is_jac_elem(val)):
+    if is_jac_elem(val):
         val = jac_elem_unwrap(val, parent=parent)
-    elif (isinstance(val, list)):
+    elif isinstance(val, list):
         for i in range(len(val)):
             val[i] = jac_unwrap_value(val[i], parent=parent)
-    elif (isinstance(val, dict)):
+    elif isinstance(val, dict):
         for i in val.keys():
             val[i] = jac_unwrap_value(val[i], parent=parent)
     return jac_type_unwrap(val)
 
 
-class jac_value():
+class jac_value:
     """
     A reference to a variable in context dict that is common for elements
     """
@@ -143,55 +142,60 @@ class jac_value():
         self.value = self.setup_value(value)
 
     def setup_value(self, value):
-        if (isinstance(self.ctx, element)):
+        if isinstance(self.ctx, element):
             self.is_element = self.ctx
-            if(self.parent._assign_mode):
+            if self.parent._assign_mode:
                 self.is_element.save()
             self.ctx = self.ctx.context
         if value is not None:
             return value
-        elif(self.ctx is not None and self.name is not None):
-            if(self.end is not None):
-                return self.ctx[self.name:self.end]
-            elif(type(self.name) == int or self.name in self.ctx.keys()):
+        elif self.ctx is not None and self.name is not None:
+            if self.end is not None:
+                return self.ctx[self.name : self.end]
+            elif type(self.name) == int or self.name in self.ctx.keys():
                 return self.ctx[self.name]
         else:
             return None
 
     def write(self, jac_ast, force=False):
-        if(not force and self.is_element and self.name not in self.ctx.keys()
-           and not self.parent.parent().
-           check_in_arch_context(self.name, self.is_element)):
+        if (
+            not force
+            and self.is_element
+            and self.name not in self.ctx.keys()
+            and not self.parent.parent().check_in_arch_context(
+                self.name, self.is_element
+            )
+        ):
             self.parent.rt_error(
                 f"Creating variable {self.name} in graph "
                 f"element {type(self.is_element)} is not allowed, "
                 "please define",
-                jac_ast)
-        elif(self.ctx is None or self.name is None):
+                jac_ast,
+            )
+        elif self.ctx is None or self.name is None:
             self.parent.rt_error(
-                f"No valid live variable! ctx: {self.ctx} name: {self.name}",
-                jac_ast)
-        elif(self.end is not None):
-            self.ctx[self.name:self.end] = self.wrap()
+                f"No valid live variable! ctx: {self.ctx} name: {self.name}", jac_ast
+            )
+        elif self.end is not None:
+            self.ctx[self.name : self.end] = self.wrap()
         else:
             self.ctx[self.name] = self.wrap()
 
     def self_destruct(self, jac_ast):
-        if(self.is_element and self.name in self.ctx.keys()):
+        if self.is_element and self.name in self.ctx.keys():
             self.parent.rt_error(
                 f"Deleting {self.name} in graph element "
                 f"{type(self.is_element)} is not allowed, try setting to null",
-                jac_ast)
+                jac_ast,
+            )
             return
-        if(self.ctx is not None):
+        if self.ctx is not None:
             try:
                 del self.ctx[self.name]
             except Exception as e:
-                self.parent.rt_error(f'{e}', jac_ast)
+                self.parent.rt_error(f"{e}", jac_ast)
         else:
-            self.parent.rt_error(
-                f'{self.value} is not destroyable',
-                jac_ast)
+            self.parent.rt_error(f"{self.value} is not destroyable", jac_ast)
 
     def wrap(self, serialize_mode=False):
         "Caller for recursive wrap"
