@@ -158,7 +158,6 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report[14], 180)
 
     def test_reffy_deref_check(self):
-        self.logger_on()
         mast = master(h=mem_hook())
         mast.sentinel_register(name="test", code=jtp.reffy_deref_check, auto_run="")
         report = mast.general_interface_to_api(
@@ -166,3 +165,44 @@ class jac_tests(TestCaseHelper, TestCase):
         )["report"]
         self.assertFalse(report[0])
         self.assertTrue(report[1])
+
+    def test_vanishing_can_check(self):
+        mast = super_master(h=mem_hook())
+        mast.actions_load_local("jaseci/tests/infer.py")
+        mast.sentinel_register(name="test", code=jtp.vanishing_can_check, auto_run="")
+        mast.general_interface_to_api(api_name="walker_run", params={"name": "init"})
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )["report"]
+        self.assertEqual(report, ["2022-01-01T00:00:00"])
+        mast.propagate_access("public")
+        mast2 = super_master(h=mast._h)
+        mast.active_snt().run_architype(name="plain", kind="node", caller=mast2)
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )["report"]
+        self.assertEqual(report, ["2022-01-01T00:00:00"])
+
+    def test_jasecilib_alias_list(self):
+        mast = master(h=mem_hook())
+        mast.sentinel_register(name="test", code=jtp.jasecilib_alias_list, auto_run="")
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )["report"]
+        self.assertGreater(len(report[0].keys()), 3)
+
+    def test_jasecilib_params(self):
+        mast = master(h=mem_hook())
+        mast.sentinel_register(name="test", code=jtp.jasecilib_params, auto_run="")
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )["report"]
+        self.assertIn("j_r_acc_ids", report[0][0].keys())
+
+    def test_jasecilib_create_user(self):
+        mast = master(h=mem_hook())
+        mast.sentinel_register(name="test", code=jtp.jasecilib_create_user, auto_run="")
+        report = mast.general_interface_to_api(
+            api_name="walker_run", params={"name": "init"}
+        )["report"]
+        self.assertEqual(report[0]["name"], ("daman@gmail.com",))
